==> haskell-authenticate-oauth-1.6-31-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-authenticate-oauth.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: authenticate-oauth
version: 1.6
id: authenticate-oauth-1.6-8ilX1bHq1fpCJZ4QQ2LV6H
key: authenticate-oauth-1.6-8ilX1bHq1fpCJZ4QQ2LV6H
license: BSD-3-Clause
maintainer: Hiromi Ishii, Artem Chirkin
author: Hiromi Ishii
stability: Stable
homepage: http://github.com/yesodweb/authenticate
synopsis: Library to authenticate with OAuth for Haskell web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate-oauth>.
category: Web
abi: baa0e7c31d6835cb5646b634739499b0
exposed: True
exposed-modules:
    Web.Authenticate.OAuth Web.Authenticate.OAuth.IO
import-dirs: /usr/lib/ghc-8.4.3/site-local/authenticate-oauth-1.6
library-dirs: /usr/lib/ghc-8.4.3/site-local/authenticate-oauth-1.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/authenticate-oauth-1.6
hs-libraries: HSauthenticate-oauth-1.6-8ilX1bHq1fpCJZ4QQ2LV6H
depends:
    RSA-2.3.0-EhYhzn6oJtn1RoK2ilE4Nr SHA-1.6.4.4-J97i4k52krALB5u9VxmQ73
    base-4.11.1.0 base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37
    blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028 bytestring-0.10.8.2
    crypto-pubkey-types-0.4.3-21qB40pgZ9ypx8jkhkukE
    data-default-0.7.1.1-6pNGRUfj5nU7unWVd8ajT0
    http-client-0.5.13.1-5ctzeCsWHcPJ877FU28ph4
    http-types-0.12.1-II9Izt8nVfhCfceL6igA2T
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV time-1.8.0.2 transformers-0.5.5.0
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
abi-depends: RSA-2.3.0-EhYhzn6oJtn1RoK2ilE4Nr=310bdd14afb06d3600f678853688d21b
             SHA-1.6.4.4-J97i4k52krALB5u9VxmQ73=7fdfeaf1e3416ffd434c90cf824fb303
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37=65adc4f5f54a1c07291b4ebc49756c05
             blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028=f952a1ec5abae3e4435518edbfd82e4e
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             crypto-pubkey-types-0.4.3-21qB40pgZ9ypx8jkhkukE=446d92453474bdf3db9af71b4f8ecc8d
             data-default-0.7.1.1-6pNGRUfj5nU7unWVd8ajT0=e2403b7ea90422302496191f03ca1dc3
             http-client-0.5.13.1-5ctzeCsWHcPJ877FU28ph4=ee0b85183d052f0418e0355e32900cbe
             http-types-0.12.1-II9Izt8nVfhCfceL6igA2T=b23e50a639b630c1d82e921bfca06775
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=2cade9e72fa19fe7a43e5ace84505d9f
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=8fe746d31ebcf312c14c2777ca0f137c
haddock-interfaces: /usr/share/doc/haskell-authenticate-oauth/html/authenticate-oauth.haddock
haddock-html: /usr/share/doc/haskell-authenticate-oauth/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-authenticate-oauth-1.6-32-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-authenticate-oauth.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: authenticate-oauth
version: 1.6
id: authenticate-oauth-1.6-9ZmiTqAbqTF42xZqhUdbzS
key: authenticate-oauth-1.6-9ZmiTqAbqTF42xZqhUdbzS
license: BSD-3-Clause
maintainer: Hiromi Ishii, Artem Chirkin
author: Hiromi Ishii
stability: Stable
homepage: http://github.com/yesodweb/authenticate
synopsis: Library to authenticate with OAuth for Haskell web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate-oauth>.
category: Web
abi: c07e960bfcf160e7753e8903062aff02
exposed: True
exposed-modules:
    Web.Authenticate.OAuth Web.Authenticate.OAuth.IO
import-dirs: /usr/lib/ghc-8.4.3/site-local/authenticate-oauth-1.6
library-dirs: /usr/lib/ghc-8.4.3/site-local/authenticate-oauth-1.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/authenticate-oauth-1.6
hs-libraries: HSauthenticate-oauth-1.6-9ZmiTqAbqTF42xZqhUdbzS
depends:
    RSA-2.3.0-5muPoYEidN16dwAGGlH2c8 SHA-1.6.4.4-J97i4k52krALB5u9VxmQ73
    base-4.11.1.0 base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37
    blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028 bytestring-0.10.8.2
    crypto-pubkey-types-0.4.3-21qB40pgZ9ypx8jkhkukE
    data-default-0.7.1.1-6pNGRUfj5nU7unWVd8ajT0
    http-client-0.5.13.1-5ctzeCsWHcPJ877FU28ph4
    http-types-0.12.1-II9Izt8nVfhCfceL6igA2T
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV time-1.8.0.2 transformers-0.5.5.0
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
abi-depends: RSA-2.3.0-5muPoYEidN16dwAGGlH2c8=d0fd243c557f6dea2ab8a875c55caf35
             SHA-1.6.4.4-J97i4k52krALB5u9VxmQ73=7fdfeaf1e3416ffd434c90cf824fb303
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37=65adc4f5f54a1c07291b4ebc49756c05
             blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028=f952a1ec5abae3e4435518edbfd82e4e
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             crypto-pubkey-types-0.4.3-21qB40pgZ9ypx8jkhkukE=446d92453474bdf3db9af71b4f8ecc8d
             data-default-0.7.1.1-6pNGRUfj5nU7unWVd8ajT0=e2403b7ea90422302496191f03ca1dc3
             http-client-0.5.13.1-5ctzeCsWHcPJ877FU28ph4=ee0b85183d052f0418e0355e32900cbe
             http-types-0.12.1-II9Izt8nVfhCfceL6igA2T=b23e50a639b630c1d82e921bfca06775
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=2cade9e72fa19fe7a43e5ace84505d9f
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=8fe746d31ebcf312c14c2777ca0f137c
haddock-interfaces: /usr/share/doc/haskell-authenticate-oauth/html/authenticate-oauth.haddock
haddock-html: /usr/share/doc/haskell-authenticate-oauth/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
